@@ -4,7 +4,7 @@
 #' model to real data it is useful to simulate data according to the model using
 #' known (fixed) parameter values and to check that these "true" parameter
 #' values are (approximately) recovered by fitting the model to the simulated
-#' data. See the \strong{Plot Descriptions} section, below, for details on the
+#' data. See the **Plot Descriptions** section, below, for details on the
 #' available plots.
 #'
 #' @name MCMC-recover
@@ -12,41 +12,41 @@
 #'
 #' @template args-mcmc-x
 #' @template args-facet_args
-#' @param true A numeric vector of "true" values of the parameters in \code{x}.
-#'   There should be one value in \code{true} for each parameter included in
-#'   \code{x} and the order of the parameters in \code{true} should be the same
-#'   as the order of the parameters in \code{x}.
+#' @param true A numeric vector of "true" values of the parameters in `x`.
+#'   There should be one value in `true` for each parameter included in
+#'   `x` and the order of the parameters in `true` should be the same
+#'   as the order of the parameters in `x`.
 #' @param batch Optionally, a vector-like object (numeric, character, integer,
-#'   factor) used to split the parameters into batches. If \code{batch} is
-#'   specified, it must have the same length as \code{true} and be in the same
-#'   order as \code{true}. Parameters in the same batch will be grouped together
-#'   in the same facet in the plot (see the \strong{Examples} section, below).
+#'   factor) used to split the parameters into batches. If `batch` is
+#'   specified, it must have the same length as `true` and be in the same
+#'   order as `true`. Parameters in the same batch will be grouped together
+#'   in the same facet in the plot (see the **Examples** section, below).
 #'   The default is to group all parameters together into a single batch.
 #'   Changing the default is most useful when parameters are on very different
-#'   scales, in which case \code{batch} can be used to group them into batches
-#'   within which it makes sense to use the same \eqn{y}-axis.
+#'   scales, in which case `batch` can be used to group them into batches
+#'   within which it makes sense to use the same y-axis.
 #' @param ... Currently unused.
 #' @param prob The probability mass to include in the inner interval. The
-#'   default is \code{0.5} (50\% interval).
+#'   default is `0.5` (50\% interval).
 #' @param prob_outer The probability mass to include in the outer interval. The
-#'   default is \code{0.9} (90\% interval).
-#' @param point_est The point estimate to show. Either \code{"median"} (the
-#'   default), \code{"mean"}, or \code{"none"}.
-#' @param size,alpha Passed to \code{\link[ggplot2]{geom_point}} to control the
+#'   default is `0.9` (90\% interval).
+#' @param point_est The point estimate to show. Either `"median"` (the
+#'   default), `"mean"`, or `"none"`.
+#' @param size,alpha Passed to [ggplot2::geom_point()] to control the
 #'   appearance of plotted points.
 #'
 #' @template return-ggplot
 #'
 #' @section Plot Descriptions:
 #' \describe{
-#'   \item{\code{mcmc_recover_intervals}}{
+#'   \item{`mcmc_recover_intervals()`}{
 #'    Central intervals and point estimates computed from MCMC draws, with
 #'    "true" values plotted using a different shape.
 #'   }
-#'   \item{\code{mcmc_recover_scatter}}{
+#'   \item{`mcmc_recover_scatter()`}{
 #'    Scatterplot of posterior means (or medians) against "true" values.
 #'   }
-#'   \item{\code{mcmc_recover_hist}}{
+#'   \item{`mcmc_recover_hist()`}{
 #'    Histograms of the draws for each parameter with the "true" value overlaid
 #'    as a vertical line.
 #'   }
@@ -58,7 +58,7 @@
 #' alpha <- 1; beta <- rnorm(10, 0, 3); sigma <- 2
 #' X <- matrix(rnorm(1000), 100, 10)
 #' y <- rnorm(100, mean = c(alpha + X %*% beta), sd = sigma)
-#' fit <- stan_glm(y ~ ., data = data.frame(y, X))
+#' fit <- stan_glm(y ~ ., data = data.frame(y, X), refresh = 0)
 #' draws <- as.matrix(fit)
 #' print(colnames(draws))
 #' true <- c(alpha, beta, sigma)
@@ -100,8 +100,8 @@ mcmc_recover_intervals <-
   function(x,
            true,
            batch = rep(1, length(true)),
-           facet_args = list(),
            ...,
+           facet_args = list(),
            prob = 0.5,
            prob_outer = 0.9,
            point_est = c("median", "mean", "none"),
@@ -121,8 +121,9 @@ mcmc_recover_intervals <-
     )
     all_separate <- length(unique(batch)) == length(true)
     point_est <- match.arg(point_est)
-    if (point_est == "none")
+    if (point_est == "none") {
       point_est <- NULL
+    }
 
     alpha1 <- (1 - prob) / 2
     alpha2 <- (1 - prob_outer) / 2
@@ -143,11 +144,9 @@ mcmc_recover_intervals <-
         factor(rownames(intervals),
                levels = rownames(intervals)[as.integer(as.factor(batch))])
     }
-    facet_args[["facets"]] <- ~ Batch
-    if (is.null(facet_args[["strip.position"]]))
-      facet_args[["strip.position"]] <- "top"
-    if (is.null(facet_args[["scales"]]))
-      facet_args[["scales"]] <- "free"
+    facet_args[["facets"]] <- "Batch"
+    facet_args[["strip.position"]] <- facet_args[["strip.position"]] %||% "top"
+    facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
 
     plot_caption <- paste0("Showing ", round(prob * 100, 1), "% and ",
                            round(prob_outer * 100, 1), "% intervals")
@@ -162,15 +161,17 @@ mcmc_recover_intervals <-
         size = 2,
         lineend = "round",
         show.legend = FALSE
-      )
+      ) +
+      bayesplot_theme_get()
 
-    if (!is.null(point_est))
+    if (!is.null(point_est)) {
       graph <- graph +
       geom_point(
         aes_(y = ~ Point, shape = "Estimated",
              color = "Estimated", fill = "Estimated"),
         size = size
       )
+    }
 
     graph <- graph +
       geom_point(
@@ -198,13 +199,14 @@ mcmc_recover_intervals <-
       xaxis_title(FALSE) +
       yaxis_title(FALSE)
 
-    if (all_separate)
+    if (all_separate) {
       return(
         graph +
           theme(axis.line.x = element_blank()) +
           xaxis_ticks(FALSE) +
           xaxis_text(FALSE)
       )
+    }
 
     graph +
       xaxis_text(face = "bold") +
@@ -218,70 +220,79 @@ mcmc_recover_scatter <-
   function(x,
            true,
            batch = rep(1, length(true)),
-           facet_args = list(),
            ...,
+           facet_args = list(),
            point_est = c("median", "mean"),
            size = 3,
            alpha = 1) {
 
-    check_ignored_arguments(...)
-    x <- merge_chains(prepare_mcmc_array(x))
+  check_ignored_arguments(...)
+  x <- merge_chains(prepare_mcmc_array(x))
 
-    stopifnot(
-      is.numeric(true),
-      ncol(x) == length(true),
-      length(batch) == length(true)
-    )
-    all_separate <- length(unique(batch)) == length(true)
-    point_est <- match.arg(point_est)
-    plot_data <- data.frame(
-      Parameter = colnames(x),
-      Point = apply(x, 2, point_est),
-      True = true
-    )
-    if (!all_separate) {
-      plot_data$Batch <- factor(batch, levels = unique(batch))
-    } else {
-      plot_data$Batch <-
-        factor(colnames(x), levels = colnames(x)[as.integer(as.factor(batch))])
-    }
+  stopifnot(
+    is.numeric(true),
+    ncol(x) == length(true),
+    length(batch) == length(true)
+  )
 
-    facet_args[["facets"]] <- ~ Batch
-    if (is.null(facet_args[["strip.position"]]))
-      facet_args[["strip.position"]] <- "top"
-    if (is.null(facet_args[["scales"]]))
-      facet_args[["scales"]] <- "free"
+  one_true_per_batch <- length(unique(batch)) == length(true)
+  one_batch <- length(unique(batch)) == 1
 
-    graph <- ggplot(plot_data, aes_(x = ~ True, y = ~ Point)) +
-      geom_abline(
-        slope = 1,
-        intercept = 0,
-        linetype = 2,
-        color = "black"
-      ) +
-      geom_point(
-        shape = 21,
-        color = get_color("mh"),
-        fill = get_color("m"),
-        size = size,
-        alpha = alpha
-      ) +
-      do.call("facet_wrap", facet_args) +
-      labs(y = "Estimated", x = "True")
+  point_est <- match.arg(point_est)
+  plot_data <- data.frame(
+    Parameter = colnames(x),
+    Point = apply(x, 2, point_est),
+    True = true
+  )
 
-    if (length(unique(batch)) == 1) {
-      g <- ggplot_build(graph)
-      xylim <- g$layout$panel_ranges[[1]]
-      xylim <- range(xylim$y.range, xylim$x.range)
-      graph <- graph + coord_fixed(xlim = xylim, ylim = xylim)
-    }
-
-    if (all_separate)
-      return(graph)
-
-    graph + facet_text(FALSE)
+  if (!one_true_per_batch) {
+    plot_data$Batch <- factor(batch, levels = unique(batch))
+  } else {
+    plot_data$Batch <-
+      factor(colnames(x), levels = colnames(x)[as.integer(as.factor(batch))])
   }
 
+  facet_args[["facets"]] <- "Batch"
+  facet_args[["strip.position"]] <- facet_args[["strip.position"]] %||% "top"
+  facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
+
+  # To ensure that the x and y scales have the same range, find the min and max
+  # value on each coordinate. plot them invisibly with geom_blank() later on.
+  corners <- plot_data %>%
+    group_by(.data$Batch) %>%
+    summarise(
+      min = min(pmin(.data$Point, .data$True)),
+      max = max(pmax(.data$Point, .data$True))
+    )
+
+  graph <-
+    ggplot(plot_data, aes_(x = ~ True, y = ~ Point)) +
+    geom_abline(
+      slope = 1,
+      intercept = 0,
+      linetype = 2,
+      color = "black"
+    ) +
+    geom_point(
+      shape = 21,
+      color = get_color("mh"),
+      fill = get_color("m"),
+      size = size,
+      alpha = alpha
+    ) +
+    geom_blank(aes(x = min, y = min), data = corners) +
+    geom_blank(aes(x = max, y = max), data = corners) +
+    do.call("facet_wrap", facet_args) +
+    labs(x = "True", y = "Estimated") +
+    bayesplot_theme_get()
+
+  if (one_batch) {
+    graph <- graph + facet_text(FALSE)
+  }
+
+  graph
+}
+
 
 #' @rdname MCMC-recover
 #' @export
@@ -289,9 +300,10 @@ mcmc_recover_scatter <-
 mcmc_recover_hist <-
   function(x,
            true,
-           facet_args = list(),
            ...,
-           binwidth = NULL) {
+           facet_args = list(),
+           binwidth = NULL,
+           breaks = NULL) {
 
     check_ignored_arguments(...)
     x <- merge_chains(prepare_mcmc_array(x))
@@ -304,9 +316,8 @@ mcmc_recover_hist <-
     vline_data <- data.frame(Parameter = colnames(x), True = true)
     hist_data <- melt_mcmc(x)[, -1]
 
-    facet_args[["facets"]] <- ~ Parameter
-    if (is.null(facet_args[["scales"]]))
-      facet_args[["scales"]] <- "free"
+    facet_args[["facets"]] <- "Parameter"
+    facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
 
     ggplot() +
       geom_histogram(
@@ -314,7 +325,8 @@ mcmc_recover_hist <-
         data = hist_data,
         color = get_color("lh"),
         size = .25,
-        binwidth = binwidth
+        binwidth = binwidth,
+        breaks = breaks
       ) +
       geom_vline(
         aes_(xintercept = ~ True, color = "True"),
@@ -326,6 +338,7 @@ mcmc_recover_hist <-
       scale_color_manual("", values = get_color("dh")) +
       guides(color = guide_legend(), fill = guide_legend(order = 1)) +
       dont_expand_y_axis() +
+      bayesplot_theme_get() +
       reduce_legend_spacing(0.25) +
       xaxis_title(FALSE) +
       yaxis_text(FALSE) +
